package net.sf.doolin.util;

/**
 * Defines a value that is editable.
 * 
 * @author Damien Coraboeuf
 * @param <T>
 *            Type of object to edit
 * 
 */
public class EditableValue<T> {

	private final T target;
	private final Object value;

	private boolean edited;

	/**
	 * Constructor.
	 * 
	 * @param target
	 *            Object to edit
	 * @param value
	 *            Value to take for the edition
	 */
	public EditableValue(T target, Object value) {
		this.target = target;
		this.value = value;
	}

	/**
	 * @return the target
	 */
	public T getTarget() {
		return this.target;
	}

	/**
	 * @return the value
	 */
	public Object getValue() {
		return this.value;
	}

	/**
	 * Checks if the value has been edited.
	 * 
	 * @return <code>true</code>, if is edited
	 */
	public boolean isEdited() {
		return this.edited;
	}

	/**
	 * Sets if the value has been edited
	 * 
	 * @param edited
	 *            <code>true</code>, if is edited
	 */
	public void setEdited(boolean edited) {
		this.edited = edited;
	}

}
