/*
 * Created on 27 avr. 2006
 */
package net.sf.doolin.util;

import org.apache.commons.lang.ObjectUtils;

/**
 * Immutable association of two objects.
 * 
 * @author Damien Coraboeuf
 * @param <A>
 *            Type of the first element of the pair
 * @param <B>
 *            Type of the second element of the pair
 */
public class Pair<A, B> {

	private final A firstValue;
	private final B secondValue;

	/**
	 * Constructor with two values.
	 * 
	 * @param a
	 *            First value
	 * @param b
	 *            Second value
	 */
	public Pair(A a, B b) {
		this.firstValue = a;
		this.secondValue = b;
	}

	@Override
	public boolean equals(Object obj) {
		if (obj instanceof Pair<?, ?>) {
			Pair<?, ?> item = (Pair<?, ?>) obj;
			return ObjectUtils.equals(this.firstValue, item.firstValue)
					&& ObjectUtils.equals(this.secondValue, item.secondValue);
		} else {
			return false;
		}
	}

	/**
	 * @return Returns the firstValue.
	 */
	public A getFirstValue() {
		return this.firstValue;
	}

	/**
	 * @return Returns the secondValue.
	 */
	public B getSecondValue() {
		return this.secondValue;
	}

	@Override
	public int hashCode() {
		return ObjectUtils.hashCode(this.firstValue)
				* ObjectUtils.hashCode(this.secondValue);
	}

	@Override
	public String toString() {
		return this.firstValue + "," + this.secondValue;
	}
}
