package net.sf.doolin.util;

import java.io.File;
import java.io.FileFilter;
import java.text.ParseException;

/**
 * This pattern works with DOS like patterns. Only the "*" wildcard is
 * supported.
 * 
 * @author Damien Coraboeuf
 * @see net.sf.doolin.util.PatternFormat
 */
public class PatternFileFilter implements FileFilter {
	/**
	 * Format used
	 */
	private PatternFormat format;

	/**
	 * Initialization
	 * 
	 * @param pattern
	 *            Pattern to be used.
	 */
	public PatternFileFilter(String pattern) {
		this.format = new PatternFormat(pattern);
	}

	/**
	 * @see java.io.FileFilter#accept(File)
	 */
	public boolean accept(File file) {
		return accept(file.getName());
	}

	/**
	 * Checks if a file name (or any string) complies with the pattern.
	 * 
	 * @param fileName
	 *            String to check
	 * @return Result of the check.
	 * @see PatternFormat#accept(String)
	 */
	public boolean accept(String fileName) {
		try {
			Object[] content = this.format.parse(fileName);
			String value = this.format.format(content);
			return fileName.equals(value);
		} catch (ParseException ex) {
			return false;
		}
	}

	/**
	 * Format a string using some parameters.
	 * 
	 * @param params
	 *            Parameters to include in the formatted string
	 * @return Formatted string.
	 * @see PatternFormat#format(Object[])
	 */
	public String format(Object... params) {
		return this.format.format(params);
	}

}
