/**
 * 
 */
package net.sf.doolin.util.expression;

import net.sf.jstring.JStrings;

import java.util.ArrayList;
import java.util.List;
import java.util.Locale;


/**
 * Token for a <code>#{...}</code> token.
 * 
 * @author Damien Coraboeuf
 * 
 */
public class KeyToken extends TokenList {

	private String key;

	private boolean switchToParams;

	/**
	 * Constructor.
	 */
	public KeyToken() {
		super(TokenType.KEY);
		this.key = "";
		this.switchToParams = false;
	}

	@Override
	public void add(Token add) {
		if (this.switchToParams) {
			super.add(add);
		} else {
			throw new IllegalStateException(
					"Cannot add an expression to the key");
		}
	}

	@Override
	public Token addText(char c) {
		if (this.switchToParams) {
			return super.addText(c);
		} else {
			this.key += c;
			return null;
		}
	}

	@Override
	public Object evaluate(Locale locale, Object context) {
		// Evaluates each token
		List<Object> evaluations = new ArrayList<Object>();
		for (Token token : getTokens()) {
			Object value = token.evaluate(locale, context);
			evaluations.add(value);
		}
		Object[] params = evaluations.toArray();
		String value = JStrings.get(locale, this.key, params);
		return value;
	}

	/**
	 * Checks if the token is currently evaluating its parameters.
	 * 
	 * @return <code>true</code> if the token is currently evaluating its
	 *         parameters.
	 */
	public boolean hasSwitchedToParams() {
		return this.switchToParams;
	}

	/**
	 * Switch to the evaluation of the parameters, after the : character.
	 * 
	 * @see #hasSwitchedToParams()
	 */
	public void switchToParams() {
		this.switchToParams = true;
	}

	@Override
	public void visitTokensWith(TokenVisitor visitor) {
		visitor.visitKeyToken(this);
		super.visitTokensWith(visitor);
	}

}